The HentaiVerse

23618
1595
1317
0
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

You gain the effect Spirit Shield.
You gain the effect Spark of Life.
You gain the effect Shadow Veil.
You gain the effect Hastened.
You gain the effect Protection.
Spawned Monster B: MID=103294 (Peerlesssss2 Oak Staff) LV=369 HP=90914
Spawned Monster A: MID=194294 (Touch) LV=369 HP=90914
Initializing arena challenge #32 (Round 1 / 85) ...

Flee
Scan
Shield Bash | Vital Strike | Merciful Blow

Fiery Blast | Inferno
Freeze | Blizzard
Shockblast | Chained Lightning
Gale | Downburst
Smite | Banishment
Corruption | Disintegrate
Drain | Weaken | Imperil
Slow | Sleep | Confuse
Blind | Silence | MagNet
Cure | Regen | Full-Cure
Protection | Haste | Shadow Veil
Absorb | Spark of Life | Spirit Shield
Heartseeker | Arcane Focus

P
1
Health Draught
2
Health Potion
3
Health Elixir
4
Mana Draught
5
Mana Potion
6
Mana Elixir
7
Spirit Draught
8
Spirit Potion
9
Spirit Elixir
10
11
12
13
14
15
S1
S2
S3
S4
S5
S6
N1
N2
N3
N4
N5
N6
369
Touch
369
Peerlesssss2 Oak Staff